@@ -72,7 +72,7 @@ Explode.explodeSelection = function(di, toolTitle) {
     var storage = document.getStorage();
     var ids = document.querySelectedEntities();
     var i, k, e, n;
-    var polyline, shapes, shape;
+    var polyline, shapes;
 
     var options = {};
     options["splineTolerance"] = RSettings.getDoubleValue("Explode/SplineTolerance", 0.01);
@@ -83,11 +83,15 @@ Explode.explodeSelection = function(di, toolTitle) {
     options["multilineTextToSimpleText"] = RSettings.getBoolValue("Explode/MultilineTextToSimpleText", true);
 
     var op = new RAddObjectsOperation();
-
     if (!isNull(toolTitle)) {
         op.setText(toolTitle);
     }
 
+    // map old block reference IDs to block reference entities:
+    var blockReferenceMap = {};
+    // list of attribute entities:
+    var attributeEntities = [];
+
     for (i=0; i<ids.length; i++) {
         var id = ids[i];
         var entity = document.queryEntity(id);
@@ -113,17 +117,28 @@ Explode.explodeSelection = function(di, toolTitle) {
             // add entities based on shapes that resulted from the explosion:
             for (k=0; k<news.length; k++) {
                 if (isEntity(news[k])) {
+                    var newEntity = news[k];
+
                     // add entities based on entities that resulted from the explosion:
-                    op.addObject(news[k], false);
+                    op.addObject(newEntity, false, true);
+
+                    if (isBlockReferenceEntity(newEntity)) {
+                        qDebug("old block ref id: ", newEntity.getId());
+                        blockReferenceMap[newEntity.getId()] = newEntity;
+                    }
+                    else if (isAttributeEntity(newEntity)) {
+                        attributeEntities.push(newEntity);
+                    }
                 }
                 else {
-                    shape = news[k];
-                    e = shapeToEntity(entity.getDocument(), shape);
+                    var newShape = news[k];
+
+                    e = shapeToEntity(entity.getDocument(), newShape);
                     if (!isNull(e)) {
                         e.setSelected(true);
                         e.copyAttributesFrom(entity.data());
-                        if (!isNull(shape.color)) {
-                            e.setColor(new RColor(shape.color));
+                        if (!isNull(newShape.color)) {
+                            e.setColor(new RColor(newShape.color));
                         }
                         op.addObject(e, false);
                     }
@@ -138,8 +153,31 @@ Explode.explodeSelection = function(di, toolTitle) {
             op.deleteObject(entity);
         }
     }
-
     di.applyOperation(op);
+
+    // update block reference attributes:
+    if (attributeEntities.length>0) {
+        op = new RAddObjectsOperation();
+        //op.setTransactionGroup(doc.getTransactionGroup());
+        if (!isNull(toolTitle)) {
+            op.setText(toolTitle);
+        }
+
+        // fix attribute links to block references:
+        for (i=0; i<attributeEntities.length; i++) {
+            var attributeEntity = attributeEntities[i].clone();
+
+            // find parent entity of attribute:
+            var blockReferenceEntity = blockReferenceMap[attributeEntity.getParentId()];
+            if (!isNull(blockReferenceEntity)) {
+                // update parent ID:
+                storage.setEntityParentId(attributeEntity, blockReferenceEntity.getId());
+                op.addObject(attributeEntity, false);
+            }
+        }
+
+        di.applyOperation(op);
+    }
 };
 
 /**
@@ -471,8 +509,10 @@ Explode.explodeEntity = function(entity, options) {
 
                 e = subEntity.clone();
                 //data.applyColumnRowOffsetTo(e, col, row);
-                storage.setObjectId(e, RObject.INVALID_ID);
+                // we need the old ID to update attribute parent IDs:
+                //storage.setObjectId(e, RObject.INVALID_ID);
                 e.setBlockId(document.getCurrentBlockId());
+
                 e.setSelected(true);
                 ret.push(e);
             }
