@@ -863,9 +863,9 @@ function entityTypeToString(type, plural) {
     case RS.EntityDimAngular:
         return plural ? qsTr("Angular Dimensions") : qsTr("Angular Dimension");
     case RS.EntityDimAngular2L:
-        return plural ? qsTr("2 Line Angular Dimensions") : qsTr("2 Line Angular Dimension");
+        return plural ? qsTr("Angular Dimensions (2 Line)") : qsTr("Angular Dimension (2 Line)");
     case RS.EntityDimAngular3P:
-        return plural ? qsTr("3 Point Angular Dimensions") : qsTr("3 Point Angular Dimension");
+        return plural ? qsTr("Angular Dimensions (3 Point)") : qsTr("Angular Dimension (3 Point)");
     case RS.EntityDimArcLength:
         return plural ? qsTr("Arc Dimension") : qsTr("Arc Dimension");
     case RS.EntityDimDiametric:
@@ -914,6 +914,18 @@ function entityTypeToString(type, plural) {
     }
 }
 
+function translateFilterStrings(filterStrings) {
+    for (var i=0; i<filterStrings.length; i++) {
+        filterStrings[i] = filterStrings[i].replace("All CAD Files", qsTr("All CAD Files"));
+        filterStrings[i] = filterStrings[i].replace("DXF Files", qsTr("DXF Files"));
+        filterStrings[i] = filterStrings[i].replace("SVG Files", qsTr("SVG Files"));
+        filterStrings[i] = filterStrings[i].replace("DXF Drawing", qsTr("DXF Drawing"));
+        filterStrings[i] = filterStrings[i].replace("DWG Drawing", qsTr("DWG Drawing"));
+        filterStrings[i] = filterStrings[i].replace("PDF File", qsTr("PDF File"));
+    }
+    return filterStrings;
+}
+
 /**
  * Checks the type of the given object.
  *
@@ -1339,6 +1351,21 @@ Array.prototype.remove = function(val, compareFunction) {
     }
 };
 
+/**
+ * Removes all matches of the given value from the array.
+ * \param The value(s) to remove.
+ */
+Array.prototype.removeAll = function() {
+    var what, a = arguments, l = a.length, ax;
+    while (l && this.length) {
+        what = a[--l];
+        while ((ax = this.indexOf(what)) !== -1) {
+            this.splice(ax, 1);
+        }
+    }
+    return this;
+};
+
 /**
  * Remove the first case insensitive match of the given string value from the array.
  * \param val The value to remove.
@@ -1384,31 +1411,6 @@ Array.prototype.sortNumerical = function() {
     Array.prototype.sort.call(this, function(a,b) { return a - b });
 }
 
-//Array.alphaNumericalSorter = function(a, b) {
-//    var aVal = parseInt(a);
-//    var bVal = parseInt(b);
-//    if (isNaN(aVal) && isNaN(bVal)) {
-//        // alphabetical:
-//        return a.localeCompare(b);
-//    }
-//    else if (isNaN(aVal)) {
-//        // text before numbers:
-//        return -1;
-//    }
-//    else if (isNaN(bVal)) {
-//        // numbers after texts:
-//        return 1;
-//    }
-//    else {
-//        // nummerical:
-//        return aVal - bVal;
-//    }
-//};
-
-/**
- * Obsolete.
- * Use RS.compareAlphanumerical instead.
- */
 Array.alphaNumericalSorter = function(a, b) {
     return RS.compareAlphanumerical(a, b);
 };
@@ -1748,7 +1750,7 @@ function coordinateToString(coordinate, decimals, relative, polar, doc) {
     var second;
     var sep;
     if (polar) {
-        sep = RSettings.getStringValue("Input/PolarCoordinateSeparator", "<");
+        sep = RSettings.getPolarCoordinateSeparator();
         if (!isNull(doc)) {
             first = doc.formatLinear(coordinate.getMagnitude());
             second = doc.formatAngle(coordinate.getAngle());
@@ -1759,7 +1761,7 @@ function coordinateToString(coordinate, decimals, relative, polar, doc) {
         }
     }
     else {
-        sep = RSettings.getStringValue("Input/CartesianCoordinateSeparator", ",");
+        sep = RSettings.getCartesianCoordinateSeparator();
         if (!isNull(doc)) {
             first = doc.formatLinear(coordinate.x);
             second = doc.formatLinear(coordinate.y);
@@ -1772,10 +1774,7 @@ function coordinateToString(coordinate, decimals, relative, polar, doc) {
 
     var prefix;
     if (relative) {
-        prefix = RSettings.getStringValue(
-                    "Input/RelativeCoordinatePrefix",
-                    String.fromCharCode(64)  // @ (doxygen can't cope with an @ here)
-        );
+        prefix = RSettings.getRelativeCoordinatePrefix();
     }
     else {
         prefix = "";
@@ -2388,24 +2387,39 @@ function autoIconPath(path) {
 function applyTheme() {
     var theme = RSettings.getValue("Theme/ThemeName", undefined);
     if (!isNull(theme)) {
-        var prefix = "themes/" + theme + "/";
-        var fn = prefix + "stylesheet.css";
-        if (new QFileInfo(fn).exists()) {
-            var file = new QFile(fn);
-            var flags = new QIODevice.OpenMode(QIODevice.ReadOnly | QIODevice.Text);
-            if (file.open(flags)) {
-                var textStream = new QTextStream(file);
-                var allLines = textStream.readAll();
-                file.close();
-                allLines = allLines.replace(/url\(/g, "url(" + prefix);
-                qApp.setStyleSheet(allLines);
-                return;
+        var path = "themes/" + theme + "/";
+
+        qApp.styleSheet = "";
+
+        // load stylesheet.css, stylesheet_[win|macos|linux].css:
+        var found = false;
+        var systemId = RS.getSystemId();
+        if (systemId==="osx") systemId = "macos";
+
+        var postfixes = ["", "_" + systemId];
+        for (var i=0; i<postfixes.length; i++) {
+            var postfix = postfixes[i];
+            var fn = path + "stylesheet" + postfix + ".css";
+            qDebug("trying to load theme stylesheet: ", fn);
+            if (new QFileInfo(fn).exists()) {
+                var file = new QFile(fn);
+                var flags = new QIODevice.OpenMode(QIODevice.ReadOnly | QIODevice.Text);
+                if (file.open(flags)) {
+                    var textStream = new QTextStream(file);
+                    var allLines = textStream.readAll();
+                    file.close();
+                    allLines = allLines.replace(/url\(/g, "url(" + path);
+                    qApp.styleSheet = qApp.styleSheet + "\n" + allLines;
+                    found = true;
+                }
             }
         }
-        if (theme!=="Default") {
-            qWarning("Cannot open theme: ", theme);
+
+        if (!found) {
+            if (theme!=="Default") {
+                qWarning("Cannot open theme: ", theme);
+            }
         }
-        qApp.setStyleSheet("");
     }
 }
 
@@ -2430,20 +2444,50 @@ function writeTextFile(fileName, str) {
         textStream.writeString(str);
     }
     file.close();
-};
+}
+
+function getKeyboardModifiers(event) {
+    if (!isNull(event)) {
+        if (isFunction(event.getModifiers)) {
+            return event.getModifiers();
+        }
+        else {
+            return event.modifiers();
+        }
+    }
 
-function getKeyboardModifiers() {
     if (RSettings.isQt(5)) {
-        return QGuiApplication.keyboardModifiers();
+        return QGuiApplication.queryKeyboardModifiers();
     }
     else {
-        return QApplication.keyboardModifiers();
+        return QApplication.queryKeyboardModifiers();
     }
-};
+}
 
-function isShiftPressed() {
-    return getKeyboardModifiers().valueOf() & Qt.ShiftModifier.valueOf();
-};
+function isShiftPressed(event) {
+    return (getKeyboardModifiers(event) & Qt.ShiftModifier) > 0 ||
+           (getKeyboardModifiers() & Qt.ShiftModifier) > 0;
+}
+
+function isAltPressed(event) {
+    return (getKeyboardModifiers(event) & Qt.AltModifier) > 0 ||
+           (getKeyboardModifiers() & Qt.AltModifier) > 0;
+}
+
+function isControlPressed(event) {
+    return (getKeyboardModifiers(event) & Qt.ControlModifier) > 0 ||
+           (getKeyboardModifiers() & Qt.ControlModifier) > 0;
+}
+
+function createSpatialIndex() {
+    if (!isNull(global.SpatialIndexClass)) {
+        // use class defined as global variable "SpatialIndexClass":
+        // allows plugins to override the default spatial index class:
+        return new global[global.SpatialIndexClass]();
+    }
+    //return new RSpatialIndexSimple();
+    return new RSpatialIndexNavel();
+}
 
 // Qt 4 API workaround:
 function qsTranslate2(context, sourceText, disambiguation, n) {
